==> netCoin_1.1.24.tar.gz: netCoin/inst/www/ca.js <==
// texts to translate
var texts = {
    netselection : "Grafo",
    nodes : "Nodes",
    general: "General",
    links: "Enllaços",
    apply: "Aplicar",
    filter: "Filtre",
    select: "Escull",
    clear: "Net",
    add: "Afegeix",
    simpleadvanced: "Senzill/Avançat",
    nodesattributes: "Atributs dels nodes",
    linksattributes: "Atributs dels enllaços",
    noitemsselected: "Cap element seleccionat",
    alertnonodes: "Cap node seleccionat! Prem els nodes per a seleccionar-los.",
    alertnonodestable: "Cap node seleccionat. No nodes selected en la taula!",
    repulsion: "Repulsió",
    distance: "Distància",
    loading: "Carregant...",
    pdfexport: "PDF exportació",
    svgexport: "SVG exportació",
    showhidelegend: "Mostra/oculta llegenda",
    showhideaxes: "Mostra/oculta eixos",
    showhideimages: "Mostra/oculta imatges",
    showhidesidebar: "Mostra/oculta barra lateral",
    showhidebuttons: "Mostra/oculta botons",
    showhidetables: "Mostra/oculta taules",
    stopresume: "Aturar/Rependre",
    netheatmap: "Xarxa/map de calor",
    isolateselection: "Filtre",
    resetfilter: "Restablir filtre",
    selectall: "Selecció tots/cap nodes",
    selectneighbors: "Afegir veïns",
    egoNet: "EgoNet",
    expandcollapse: "Expandir/contraure",
    tableselection: "Marcats en la taula",
    reset: "Restaurar",
    directional: "Mostra/oculta fletxes",
    degree: "Grau",
    none: "Cap",
    downloadtable: "Descarrega la taula",
    total: "Total",
    concoincidences: "Coincidències condicionals",
    coincidences: "Coincidències",
    ofsomeone: "de",
    withsomeone: "amb",
    incidences: "Incidències",
    expected: "Esperades",
    expectedconfidence: "+/- Confiança esperada",
    confidenceinterval: "+/- Interval de confiança",
    subjectselect: "Esdeveniment",
    Label: "Etiqueta",
    LabelSize: "Gra.Eti.",
    Group: "Grup",
    Order: "Ordre",
    OrderA: "Ordre A",
    OrderD: "Ordre B",
    Size: "Grandària",
    Color: "Color",
    Shape: "Forma",
    Legend: "Llegenda",
    Width: "Amplitud",
    Weight: "Pes",
    Intensity: "Intensitat",
    Text: "Text",
    Show: "Mostra",
    Hide: "Oculta",
    circle: "cercle",
    cross: "cruz",
    diamond: "diamante",
    square: "quadrat",
    "triangle-down": "triangle-avall",
    "triangle-up": "triangle-amunt",
    trianglesquare: "Triangle/cuadrat",
    selectacolorscale: "Selecciona una escala de color",
    outof: "de",
    scenarios: "nombre d'escenaris",
    resetzoom: "Restaurar zoom",
    removefilter: "Treure filtre",
    alertrecordheatmap: "el mapa de calor no es pot gravar.",
    speed: "Velocitat"
  };

==> netCoin_1.1.26.tar.gz: netCoin/inst/www/ca.js <==
// texts to translate
var texts = {
    netselection : "Grafo",
    nodes : "Nodes",
    general: "General",
    links: "Enllaços",
    apply: "Aplicar",
    filter: "Filtre",
    select: "Escull",
    clear: "Net",
    add: "Afegeix",
    simpleadvanced: "Senzill/Avançat",
    nodesattributes: "Atributs dels nodes",
    linksattributes: "Atributs dels enllaços",
    noitemsselected: "Cap element seleccionat",
    alertnonodes: "Cap node seleccionat! Prem els nodes per a seleccionar-los.",
    alertnonodestable: "No hi ha res seleccionat a la taula!",
    repulsion: "Repulsió",
    distance: "Distància",
    loading: "Carregant...",
    pdfexport: "PDF exportació",
    svgexport: "SVG exportació",
    showhidelegend: "Mostra/oculta llegenda",
    showhideaxes: "Mostra/oculta eixos",
    showhideimages: "Mostra/oculta imatges",
    showhidesidebar: "Mostra/oculta barra lateral",
    showhidebuttons: "Mostra/oculta botons",
    showhidetables: "Mostra/oculta taules",
    stopresume: "Aturar/Rependre",
    netheatmap: "Xarxa/map de calor",
    isolateselection: "Filtre",
    resetfilter: "Restablir filtre",
    selectall: "Selecció tots/cap nodes",
    selectneighbors: "Afegir veïns",
    egoNet: "EgoNet",
    expandcollapse: "Expandir/contraure",
    tableselection: "Marcats en la taula",
    reset: "Restaurar",
    directional: "Mostra/oculta fletxes",
    degree: "Grau",
    none: "Cap",
    downloadtable: "Descarrega la taula",
    total: "Total",
    concoincidences: "Coincidències condicionals",
    coincidences: "Coincidències",
    ofsomeone: "de",
    withsomeone: "amb",
    incidences: "Incidències",
    expected: "Esperades",
    expectedconfidence: "+/- Confiança esperada",
    confidenceinterval: "+/- Interval de confiança",
    subjectselect: "Esdeveniment",
    Label: "Etiqueta",
    LabelSize: "Gra.Eti.",
    Group: "Grup",
    Order: "Ordre",
    OrderA: "Ordre A",
    OrderD: "Ordre B",
    Size: "Grandària",
    Color: "Color",
    Shape: "Forma",
    Legend: "Llegenda",
    Width: "Amplitud",
    Weight: "Pes",
    Intensity: "Intensitat",
    Text: "Text",
    Show: "Mostra",
    Hide: "Oculta",
    circle: "cercle",
    cross: "cruz",
    diamond: "diamante",
    square: "quadrat",
    "triangle-down": "triangle-avall",
    "triangle-up": "triangle-amunt",
    trianglesquare: "Triangle/cuadrat",
    selectacolorscale: "Selecciona una escala de color",
    outof: "de",
    scenarios: "nombre d'escenaris",
    resetzoom: "Restaurar zoom",
    removefilter: "Treure filtre",
    alertrecordheatmap: "el mapa de calor no es pot gravar.",
    speed: "Velocitat"
  };
